@@ -61,16 +61,23 @@ pub mod convert {
 	}
 
     /// Represents byte in from 0bxxxx_xxxx
-	pub fn byte_repr(byte: u8) -> [char; 10] {
+	pub fn byte_repr(byte: u8, reverse: bool) -> [char; 10] {
 		let mut repr: [char; 10]= ['0'; 10];
 		let char_array: [char; 8] = byte_to_char_array(byte);
 
 		repr[0] = '0';
 		repr[1] = 'b';
 
-		for i in 2..=9 {
-			repr[i] = char_array[9 - i];
-		}
+        if reverse == false {
+            for i in 2..=9 {
+                repr[i] = char_array[9 - i];
+            }
+        }
+        else {
+            for i in 2..=9 {
+                repr[i] = char_array[i - 2];
+            }
+        }
 
 		repr
 	}
@@ -146,6 +153,7 @@ mod tests {
     fn test_convert_byte_repr() {
         let byte: u8 = 0b0101_0101;
 
-        assert_eq!(convert::byte_repr(byte), ['0','b','0','1','0','1','0','1','0','1']);
+        assert_eq!(convert::byte_repr(byte, false), ['0','b','0','1','0','1','0','1','0','1']);
+        assert_eq!(convert::byte_repr(byte, true), ['0','b','1','0','1','0','1','0','1','0']);
     }
 }
